CatalogProvider class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getCatalog(
) → Map< String, dynamic> ? - Get the catalog synchronously (must call loadCatalog first).
-
getCatalogJson(
) → String? - Get the catalog as a JSON string for sending to the agent.
-
getWidgetTypes(
) → List< String> - Get available widget types from the catalog.
-
loadCatalog(
) → Future< Map< String, dynamic> > - Load the catalog from the bundled asset.