isInitialized property
bool
get
isInitialized
Whether the SDK has been initialized and the license is valid.
Implementation
static bool get isInitialized => _initialized;
Whether the SDK has been initialized and the license is valid.
static bool get isInitialized => _initialized;