widgetLimit property
int
get
widgetLimit
Max widget types allowed by the current plan (-1 = unlimited).
Implementation
static int get widgetLimit => _widgetLimit;
Max widget types allowed by the current plan (-1 = unlimited).
static int get widgetLimit => _widgetLimit;