build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
Widget result = child;
// Apply color scheme — wraps child in a Theme so that all descendants
// using Theme.of(context).colorScheme pick up the host app's colors.
if (colorScheme != null) {
final baseTheme = Theme.of(context);
result = Theme(
data: baseTheme.copyWith(colorScheme: colorScheme),
child: result,
);
}
// Apply theme override (background, border radius)
if (themeOverride != null) {
result = Container(
decoration: BoxDecoration(
color: themeOverride!.backgroundColor,
borderRadius: themeOverride!.borderRadius != null
? BorderRadius.circular(themeOverride!.borderRadius!)
: null,
),
child: DefaultTextStyle.merge(
style: TextStyle(color: themeOverride!.textColor),
child: result,
),
);
}
final l = layout;
if (l == null) {
// Default: expand to parent width, intrinsic height
return SizedBox(width: double.infinity, child: result);
}
// Apply aspect ratio
if (l.aspectRatio != null) {
result = AspectRatio(aspectRatio: l.aspectRatio!, child: result);
}
// Apply fixed size or expand
if (l.width != null || l.height != null) {
result = SizedBox(width: l.width, height: l.height, child: result);
} else if (l.expand) {
result = SizedBox(width: double.infinity, child: result);
}
// Apply max constraints
if (l.maxWidth != null || l.maxHeight != null) {
result = ConstrainedBox(
constraints: BoxConstraints(
maxWidth: l.maxWidth ?? double.infinity,
maxHeight: l.maxHeight ?? double.infinity,
),
child: result,
);
}
// Apply padding
if (l.padding != null) {
result = Padding(padding: l.padding!, child: result);
}
// Apply margin
if (l.margin != null) {
result = Container(margin: l.margin, child: result);
}
return result;
}