WidgetBuilder typedef

WidgetBuilder = Widget Function(Map<String, dynamic> params, {void onAction(String url)?})

Signature for a factory that builds a widget from JSON params. onAction is called when the widget triggers an action (e.g. button tap, link tap) and receives the target URL or action string.

Implementation

typedef WidgetBuilder = Widget Function(
  Map<String, dynamic> params, {
  void Function(String url)? onAction,
});