TriggerContext class

Constructors

TriggerContext({required String currentDate, Map<String, dynamic>? weather, List<Map<String, dynamic>> userActions = const [], Map<String, dynamic> userPreferences = const {}, Set<String> dismissedWidgets = const {}, Map<String, dynamic> developerParams = const {}})
const

Properties

currentDate String
final
developerParams Map<String, dynamic>
final
dismissedWidgets Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userActions List<Map<String, dynamic>>
final
userPreferences Map<String, dynamic>
final
weather Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited