WidgetDefinition class

Constructors

WidgetDefinition({required String id, required String name, required WidgetCategory category, required WidgetContent content, int priority = 0, int? ttlMs, double? createdAt})
const
WidgetDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

category WidgetCategory
final
content WidgetContent
final
createdAt double?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttlMs int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited