FirebaseWidgetService class

Constructors

FirebaseWidgetService({FirebaseFirestore? firestore})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismissWidget(String userId, String widgetId) Future<void>
Dismiss a widget for a user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordInteraction(String userId, String widgetId, String action) Future<void>
Record an interaction.
toString() String
A string representation of this object.
inherited
watchDismissedWidgets(String userId) Stream<Set<String>>
Stream of user state (dismissed widgets).
watchWidgets() Stream<List<WidgetEntry>>
Stream of widget entries from Firestore, sorted by priority.

Operators

operator ==(Object other) bool
The equality operator.
inherited