cache property
Optional offline cache. When provided, successful responses are stored locally and returned if a subsequent network request fails.
Implementation
final WidgetCache? cache;
Optional offline cache. When provided, successful responses are stored locally and returned if a subsequent network request fails.
final WidgetCache? cache;