core/widget_registry library

Registry that maps widget type strings to Flutter widget builders.

Classes

WidgetRegistry

Typedefs

WidgetBuilder = Widget Function(Map<String, dynamic> params)
Signature for a factory that builds a widget from JSON params.