WidgetResolver class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

resolve(Map<String, dynamic> responseJson, {ColorScheme? hostColorScheme, OnWidgetDismiss? onDismiss, OnWidgetAction? onAction}) List<Widget>
Resolve a full agent JSON response into Flutter widgets.
resolveEntries(List<WidgetEntry> entries, {ColorScheme? hostColorScheme, OnWidgetDismiss? onDismiss, OnWidgetAction? onAction}) List<Widget>
Resolve a list of WidgetEntry into Flutter widgets.
resolveSingle(WidgetEntry entry, {ColorScheme? hostColorScheme}) Widget?
Resolve a single widget entry.