CommonParams class
Common parameters shared by all widget types.
Constructors
- CommonParams({bool dismissible = true, int priority = 0, int? ttlSeconds, ThemeOverride? themeOverride, LayoutConfig? layout, ColorScheme? colorScheme})
-
const
-
CommonParams.fromJson(Map<
String, dynamic> json) -
factory
Properties
- colorScheme → ColorScheme?
-
Color scheme parsed from the agent's
color_palettefield.final - dismissible → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layout → LayoutConfig?
-
final
- priority → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themeOverride → ThemeOverride?
-
final
- ttlSeconds → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited