LayoutConfig class
Layout configuration for responsive widget sizing.
Constructors
- LayoutConfig({double? width, double? height, double? maxWidth, double? maxHeight, EdgeInsets? padding, EdgeInsets? margin, bool expand = true, double? aspectRatio})
-
const
-
LayoutConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- aspectRatio → double?
-
final
- expand → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- margin → EdgeInsets?
-
final
- maxHeight → double?
-
final
- maxWidth → double?
-
final
- padding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited